# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "allow_connections": "allowConnections",
    "bypass_row_level_security": "bypassRowLevelSecurity",
    "connection_limit": "connectionLimit",
    "create_database": "createDatabase",
    "create_role": "createRole",
    "drop_cascade": "dropCascade",
    "encrypted_password": "encryptedPassword",
    "if_not_exists": "ifNotExists",
    "is_template": "isTemplate",
    "lc_collate": "lcCollate",
    "lc_ctype": "lcCtype",
    "object_type": "objectType",
    "search_paths": "searchPaths",
    "skip_drop_role": "skipDropRole",
    "skip_reassign_owned": "skipReassignOwned",
    "statement_timeout": "statementTimeout",
    "tablespace_name": "tablespaceName",
    "valid_until": "validUntil",
    "with_grant_option": "withGrantOption",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "allowConnections": "allow_connections",
    "bypassRowLevelSecurity": "bypass_row_level_security",
    "connectionLimit": "connection_limit",
    "createDatabase": "create_database",
    "createRole": "create_role",
    "dropCascade": "drop_cascade",
    "encryptedPassword": "encrypted_password",
    "ifNotExists": "if_not_exists",
    "isTemplate": "is_template",
    "lcCollate": "lc_collate",
    "lcCtype": "lc_ctype",
    "objectType": "object_type",
    "searchPaths": "search_paths",
    "skipDropRole": "skip_drop_role",
    "skipReassignOwned": "skip_reassign_owned",
    "statementTimeout": "statement_timeout",
    "tablespaceName": "tablespace_name",
    "validUntil": "valid_until",
    "withGrantOption": "with_grant_option",
}
